@@ -3,9 +3,9 @@ Main interface for ds service type definitions.
 
 Usage::
 
-    from mypy_boto3.ds.type_defs import SharedDirectoryTypeDef
+    from mypy_boto3.ds.type_defs import AttributeTypeDef
 
-    data: SharedDirectoryTypeDef = {...}
+    data: AttributeTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,12 +22,31 @@ else:
 
 
 __all__ = (
-    "SharedDirectoryTypeDef",
-    "AcceptSharedDirectoryResultTypeDef",
     "AttributeTypeDef",
+    "CertificateInfoTypeDef",
+    "CertificateTypeDef",
+    "ComputerTypeDef",
+    "ConditionalForwarderTypeDef",
+    "DirectoryConnectSettingsDescriptionTypeDef",
+    "DirectoryDescriptionTypeDef",
+    "DirectoryLimitsTypeDef",
+    "DirectoryVpcSettingsDescriptionTypeDef",
+    "DomainControllerTypeDef",
+    "EventTopicTypeDef",
+    "IpRouteInfoTypeDef",
+    "LDAPSSettingInfoTypeDef",
+    "LogSubscriptionTypeDef",
+    "OwnerDirectoryDescriptionTypeDef",
+    "RadiusSettingsTypeDef",
+    "SchemaExtensionInfoTypeDef",
+    "SharedDirectoryTypeDef",
+    "SnapshotLimitsTypeDef",
+    "SnapshotTypeDef",
+    "TagTypeDef",
+    "TrustTypeDef",
+    "AcceptSharedDirectoryResultTypeDef",
     "ConnectDirectoryResultTypeDef",
     "CreateAliasResultTypeDef",
-    "ComputerTypeDef",
     "CreateComputerResultTypeDef",
     "CreateDirectoryResultTypeDef",
     "CreateMicrosoftADResultTypeDef",
@@ -36,43 +55,24 @@ __all__ = (
     "DeleteDirectoryResultTypeDef",
     "DeleteSnapshotResultTypeDef",
     "DeleteTrustResultTypeDef",
-    "CertificateTypeDef",
     "DescribeCertificateResultTypeDef",
-    "ConditionalForwarderTypeDef",
     "DescribeConditionalForwardersResultTypeDef",
-    "DirectoryConnectSettingsDescriptionTypeDef",
-    "DirectoryVpcSettingsDescriptionTypeDef",
-    "RadiusSettingsTypeDef",
-    "OwnerDirectoryDescriptionTypeDef",
-    "DirectoryDescriptionTypeDef",
     "DescribeDirectoriesResultTypeDef",
-    "DomainControllerTypeDef",
     "DescribeDomainControllersResultTypeDef",
-    "EventTopicTypeDef",
     "DescribeEventTopicsResultTypeDef",
-    "LDAPSSettingInfoTypeDef",
     "DescribeLDAPSSettingsResultTypeDef",
     "DescribeSharedDirectoriesResultTypeDef",
-    "SnapshotTypeDef",
     "DescribeSnapshotsResultTypeDef",
-    "TrustTypeDef",
     "DescribeTrustsResultTypeDef",
     "DirectoryConnectSettingsTypeDef",
     "DirectoryVpcSettingsTypeDef",
-    "DirectoryLimitsTypeDef",
     "GetDirectoryLimitsResultTypeDef",
-    "SnapshotLimitsTypeDef",
     "GetSnapshotLimitsResultTypeDef",
     "IpRouteTypeDef",
-    "CertificateInfoTypeDef",
     "ListCertificatesResultTypeDef",
-    "IpRouteInfoTypeDef",
     "ListIpRoutesResultTypeDef",
-    "LogSubscriptionTypeDef",
     "ListLogSubscriptionsResultTypeDef",
-    "SchemaExtensionInfoTypeDef",
     "ListSchemaExtensionsResultTypeDef",
-    "TagTypeDef",
     "ListTagsForResourceResultTypeDef",
     "PaginatorConfigTypeDef",
     "RegisterCertificateResultTypeDef",
@@ -86,80 +86,26 @@ __all__ = (
     "VerifyTrustResultTypeDef",
 )
 
-SharedDirectoryTypeDef = TypedDict(
-    "SharedDirectoryTypeDef",
+AttributeTypeDef = TypedDict("AttributeTypeDef", {"Name": str, "Value": str}, total=False)
+
+CertificateInfoTypeDef = TypedDict(
+    "CertificateInfoTypeDef",
     {
-        "OwnerAccountId": str,
-        "OwnerDirectoryId": str,
-        "ShareMethod": Literal["ORGANIZATIONS", "HANDSHAKE"],
-        "SharedAccountId": str,
-        "SharedDirectoryId": str,
-        "ShareStatus": Literal[
-            "Shared",
-            "PendingAcceptance",
-            "Rejected",
-            "Rejecting",
-            "RejectFailed",
-            "Sharing",
-            "ShareFailed",
-            "Deleted",
-            "Deleting",
+        "CertificateId": str,
+        "CommonName": str,
+        "State": Literal[
+            "Registering",
+            "Registered",
+            "RegisterFailed",
+            "Deregistering",
+            "Deregistered",
+            "DeregisterFailed",
         ],
-        "ShareNotes": str,
-        "CreatedDateTime": datetime,
-        "LastUpdatedDateTime": datetime,
+        "ExpiryDateTime": datetime,
     },
     total=False,
 )
 
-AcceptSharedDirectoryResultTypeDef = TypedDict(
-    "AcceptSharedDirectoryResultTypeDef", {"SharedDirectory": SharedDirectoryTypeDef}, total=False
-)
-
-AttributeTypeDef = TypedDict("AttributeTypeDef", {"Name": str, "Value": str}, total=False)
-
-ConnectDirectoryResultTypeDef = TypedDict(
-    "ConnectDirectoryResultTypeDef", {"DirectoryId": str}, total=False
-)
-
-CreateAliasResultTypeDef = TypedDict(
-    "CreateAliasResultTypeDef", {"DirectoryId": str, "Alias": str}, total=False
-)
-
-ComputerTypeDef = TypedDict(
-    "ComputerTypeDef",
-    {"ComputerId": str, "ComputerName": str, "ComputerAttributes": List[AttributeTypeDef]},
-    total=False,
-)
-
-CreateComputerResultTypeDef = TypedDict(
-    "CreateComputerResultTypeDef", {"Computer": ComputerTypeDef}, total=False
-)
-
-CreateDirectoryResultTypeDef = TypedDict(
-    "CreateDirectoryResultTypeDef", {"DirectoryId": str}, total=False
-)
-
-CreateMicrosoftADResultTypeDef = TypedDict(
-    "CreateMicrosoftADResultTypeDef", {"DirectoryId": str}, total=False
-)
-
-CreateSnapshotResultTypeDef = TypedDict(
-    "CreateSnapshotResultTypeDef", {"SnapshotId": str}, total=False
-)
-
-CreateTrustResultTypeDef = TypedDict("CreateTrustResultTypeDef", {"TrustId": str}, total=False)
-
-DeleteDirectoryResultTypeDef = TypedDict(
-    "DeleteDirectoryResultTypeDef", {"DirectoryId": str}, total=False
-)
-
-DeleteSnapshotResultTypeDef = TypedDict(
-    "DeleteSnapshotResultTypeDef", {"SnapshotId": str}, total=False
-)
-
-DeleteTrustResultTypeDef = TypedDict("DeleteTrustResultTypeDef", {"TrustId": str}, total=False)
-
 CertificateTypeDef = TypedDict(
     "CertificateTypeDef",
     {
@@ -180,8 +126,10 @@ CertificateTypeDef = TypedDict(
     total=False,
 )
 
-DescribeCertificateResultTypeDef = TypedDict(
-    "DescribeCertificateResultTypeDef", {"Certificate": CertificateTypeDef}, total=False
+ComputerTypeDef = TypedDict(
+    "ComputerTypeDef",
+    {"ComputerId": str, "ComputerName": str, "ComputerAttributes": List["AttributeTypeDef"]},
+    total=False,
 )
 
 ConditionalForwarderTypeDef = TypedDict(
@@ -190,12 +138,6 @@ ConditionalForwarderTypeDef = TypedDict(
     total=False,
 )
 
-DescribeConditionalForwardersResultTypeDef = TypedDict(
-    "DescribeConditionalForwardersResultTypeDef",
-    {"ConditionalForwarders": List[ConditionalForwarderTypeDef]},
-    total=False,
-)
-
 DirectoryConnectSettingsDescriptionTypeDef = TypedDict(
     "DirectoryConnectSettingsDescriptionTypeDef",
     {
@@ -209,40 +151,6 @@ DirectoryConnectSettingsDescriptionTypeDef = TypedDict(
     total=False,
 )
 
-DirectoryVpcSettingsDescriptionTypeDef = TypedDict(
-    "DirectoryVpcSettingsDescriptionTypeDef",
-    {"VpcId": str, "SubnetIds": List[str], "SecurityGroupId": str, "AvailabilityZones": List[str]},
-    total=False,
-)
-
-RadiusSettingsTypeDef = TypedDict(
-    "RadiusSettingsTypeDef",
-    {
-        "RadiusServers": List[str],
-        "RadiusPort": int,
-        "RadiusTimeout": int,
-        "RadiusRetries": int,
-        "SharedSecret": str,
-        "AuthenticationProtocol": Literal["PAP", "CHAP", "MS-CHAPv1", "MS-CHAPv2"],
-        "DisplayLabel": str,
-        "UseSameUsername": bool,
-    },
-    total=False,
-)
-
-OwnerDirectoryDescriptionTypeDef = TypedDict(
-    "OwnerDirectoryDescriptionTypeDef",
-    {
-        "DirectoryId": str,
-        "AccountId": str,
-        "DnsIpAddrs": List[str],
-        "VpcSettings": DirectoryVpcSettingsDescriptionTypeDef,
-        "RadiusSettings": RadiusSettingsTypeDef,
-        "RadiusStatus": Literal["Creating", "Completed", "Failed"],
-    },
-    total=False,
-)
-
 DirectoryDescriptionTypeDef = TypedDict(
     "DirectoryDescriptionTypeDef",
     {
@@ -284,21 +192,37 @@ DirectoryDescriptionTypeDef = TypedDict(
         "LaunchTime": datetime,
         "StageLastUpdatedDateTime": datetime,
         "Type": Literal["SimpleAD", "ADConnector", "MicrosoftAD", "SharedMicrosoftAD"],
-        "VpcSettings": DirectoryVpcSettingsDescriptionTypeDef,
-        "ConnectSettings": DirectoryConnectSettingsDescriptionTypeDef,
-        "RadiusSettings": RadiusSettingsTypeDef,
+        "VpcSettings": "DirectoryVpcSettingsDescriptionTypeDef",
+        "ConnectSettings": "DirectoryConnectSettingsDescriptionTypeDef",
+        "RadiusSettings": "RadiusSettingsTypeDef",
         "RadiusStatus": Literal["Creating", "Completed", "Failed"],
         "StageReason": str,
         "SsoEnabled": bool,
         "DesiredNumberOfDomainControllers": int,
-        "OwnerDirectoryDescription": OwnerDirectoryDescriptionTypeDef,
+        "OwnerDirectoryDescription": "OwnerDirectoryDescriptionTypeDef",
     },
     total=False,
 )
 
-DescribeDirectoriesResultTypeDef = TypedDict(
-    "DescribeDirectoriesResultTypeDef",
-    {"DirectoryDescriptions": List[DirectoryDescriptionTypeDef], "NextToken": str},
+DirectoryLimitsTypeDef = TypedDict(
+    "DirectoryLimitsTypeDef",
+    {
+        "CloudOnlyDirectoriesLimit": int,
+        "CloudOnlyDirectoriesCurrentCount": int,
+        "CloudOnlyDirectoriesLimitReached": bool,
+        "CloudOnlyMicrosoftADLimit": int,
+        "CloudOnlyMicrosoftADCurrentCount": int,
+        "CloudOnlyMicrosoftADLimitReached": bool,
+        "ConnectedDirectoriesLimit": int,
+        "ConnectedDirectoriesCurrentCount": int,
+        "ConnectedDirectoriesLimitReached": bool,
+    },
+    total=False,
+)
+
+DirectoryVpcSettingsDescriptionTypeDef = TypedDict(
+    "DirectoryVpcSettingsDescriptionTypeDef",
+    {"VpcId": str, "SubnetIds": List[str], "SecurityGroupId": str, "AvailabilityZones": List[str]},
     total=False,
 )
 
@@ -321,12 +245,6 @@ DomainControllerTypeDef = TypedDict(
     total=False,
 )
 
-DescribeDomainControllersResultTypeDef = TypedDict(
-    "DescribeDomainControllersResultTypeDef",
-    {"DomainControllers": List[DomainControllerTypeDef], "NextToken": str},
-    total=False,
-)
-
 EventTopicTypeDef = TypedDict(
     "EventTopicTypeDef",
     {
@@ -339,8 +257,19 @@ EventTopicTypeDef = TypedDict(
     total=False,
 )
 
-DescribeEventTopicsResultTypeDef = TypedDict(
-    "DescribeEventTopicsResultTypeDef", {"EventTopics": List[EventTopicTypeDef]}, total=False
+IpRouteInfoTypeDef = TypedDict(
+    "IpRouteInfoTypeDef",
+    {
+        "DirectoryId": str,
+        "CidrIp": str,
+        "IpRouteStatusMsg": Literal[
+            "Adding", "Added", "Removing", "Removed", "AddFailed", "RemoveFailed"
+        ],
+        "AddedDateTime": datetime,
+        "IpRouteStatusReason": str,
+        "Description": str,
+    },
+    total=False,
 )
 
 LDAPSSettingInfoTypeDef = TypedDict(
@@ -353,15 +282,97 @@ LDAPSSettingInfoTypeDef = TypedDict(
     total=False,
 )
 
-DescribeLDAPSSettingsResultTypeDef = TypedDict(
-    "DescribeLDAPSSettingsResultTypeDef",
-    {"LDAPSSettingsInfo": List[LDAPSSettingInfoTypeDef], "NextToken": str},
+LogSubscriptionTypeDef = TypedDict(
+    "LogSubscriptionTypeDef",
+    {"DirectoryId": str, "LogGroupName": str, "SubscriptionCreatedDateTime": datetime},
     total=False,
 )
 
-DescribeSharedDirectoriesResultTypeDef = TypedDict(
-    "DescribeSharedDirectoriesResultTypeDef",
-    {"SharedDirectories": List[SharedDirectoryTypeDef], "NextToken": str},
+OwnerDirectoryDescriptionTypeDef = TypedDict(
+    "OwnerDirectoryDescriptionTypeDef",
+    {
+        "DirectoryId": str,
+        "AccountId": str,
+        "DnsIpAddrs": List[str],
+        "VpcSettings": "DirectoryVpcSettingsDescriptionTypeDef",
+        "RadiusSettings": "RadiusSettingsTypeDef",
+        "RadiusStatus": Literal["Creating", "Completed", "Failed"],
+    },
+    total=False,
+)
+
+RadiusSettingsTypeDef = TypedDict(
+    "RadiusSettingsTypeDef",
+    {
+        "RadiusServers": List[str],
+        "RadiusPort": int,
+        "RadiusTimeout": int,
+        "RadiusRetries": int,
+        "SharedSecret": str,
+        "AuthenticationProtocol": Literal["PAP", "CHAP", "MS-CHAPv1", "MS-CHAPv2"],
+        "DisplayLabel": str,
+        "UseSameUsername": bool,
+    },
+    total=False,
+)
+
+SchemaExtensionInfoTypeDef = TypedDict(
+    "SchemaExtensionInfoTypeDef",
+    {
+        "DirectoryId": str,
+        "SchemaExtensionId": str,
+        "Description": str,
+        "SchemaExtensionStatus": Literal[
+            "Initializing",
+            "CreatingSnapshot",
+            "UpdatingSchema",
+            "Replicating",
+            "CancelInProgress",
+            "RollbackInProgress",
+            "Cancelled",
+            "Failed",
+            "Completed",
+        ],
+        "SchemaExtensionStatusReason": str,
+        "StartDateTime": datetime,
+        "EndDateTime": datetime,
+    },
+    total=False,
+)
+
+SharedDirectoryTypeDef = TypedDict(
+    "SharedDirectoryTypeDef",
+    {
+        "OwnerAccountId": str,
+        "OwnerDirectoryId": str,
+        "ShareMethod": Literal["ORGANIZATIONS", "HANDSHAKE"],
+        "SharedAccountId": str,
+        "SharedDirectoryId": str,
+        "ShareStatus": Literal[
+            "Shared",
+            "PendingAcceptance",
+            "Rejected",
+            "Rejecting",
+            "RejectFailed",
+            "Sharing",
+            "ShareFailed",
+            "Deleted",
+            "Deleting",
+        ],
+        "ShareNotes": str,
+        "CreatedDateTime": datetime,
+        "LastUpdatedDateTime": datetime,
+    },
+    total=False,
+)
+
+SnapshotLimitsTypeDef = TypedDict(
+    "SnapshotLimitsTypeDef",
+    {
+        "ManualSnapshotsLimit": int,
+        "ManualSnapshotsCurrentCount": int,
+        "ManualSnapshotsLimitReached": bool,
+    },
     total=False,
 )
 
@@ -378,11 +389,7 @@ SnapshotTypeDef = TypedDict(
     total=False,
 )
 
-DescribeSnapshotsResultTypeDef = TypedDict(
-    "DescribeSnapshotsResultTypeDef",
-    {"Snapshots": List[SnapshotTypeDef], "NextToken": str},
-    total=False,
-)
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
 
 TrustTypeDef = TypedDict(
     "TrustTypeDef",
@@ -414,8 +421,92 @@ TrustTypeDef = TypedDict(
     total=False,
 )
 
+AcceptSharedDirectoryResultTypeDef = TypedDict(
+    "AcceptSharedDirectoryResultTypeDef", {"SharedDirectory": "SharedDirectoryTypeDef"}, total=False
+)
+
+ConnectDirectoryResultTypeDef = TypedDict(
+    "ConnectDirectoryResultTypeDef", {"DirectoryId": str}, total=False
+)
+
+CreateAliasResultTypeDef = TypedDict(
+    "CreateAliasResultTypeDef", {"DirectoryId": str, "Alias": str}, total=False
+)
+
+CreateComputerResultTypeDef = TypedDict(
+    "CreateComputerResultTypeDef", {"Computer": "ComputerTypeDef"}, total=False
+)
+
+CreateDirectoryResultTypeDef = TypedDict(
+    "CreateDirectoryResultTypeDef", {"DirectoryId": str}, total=False
+)
+
+CreateMicrosoftADResultTypeDef = TypedDict(
+    "CreateMicrosoftADResultTypeDef", {"DirectoryId": str}, total=False
+)
+
+CreateSnapshotResultTypeDef = TypedDict(
+    "CreateSnapshotResultTypeDef", {"SnapshotId": str}, total=False
+)
+
+CreateTrustResultTypeDef = TypedDict("CreateTrustResultTypeDef", {"TrustId": str}, total=False)
+
+DeleteDirectoryResultTypeDef = TypedDict(
+    "DeleteDirectoryResultTypeDef", {"DirectoryId": str}, total=False
+)
+
+DeleteSnapshotResultTypeDef = TypedDict(
+    "DeleteSnapshotResultTypeDef", {"SnapshotId": str}, total=False
+)
+
+DeleteTrustResultTypeDef = TypedDict("DeleteTrustResultTypeDef", {"TrustId": str}, total=False)
+
+DescribeCertificateResultTypeDef = TypedDict(
+    "DescribeCertificateResultTypeDef", {"Certificate": "CertificateTypeDef"}, total=False
+)
+
+DescribeConditionalForwardersResultTypeDef = TypedDict(
+    "DescribeConditionalForwardersResultTypeDef",
+    {"ConditionalForwarders": List["ConditionalForwarderTypeDef"]},
+    total=False,
+)
+
+DescribeDirectoriesResultTypeDef = TypedDict(
+    "DescribeDirectoriesResultTypeDef",
+    {"DirectoryDescriptions": List["DirectoryDescriptionTypeDef"], "NextToken": str},
+    total=False,
+)
+
+DescribeDomainControllersResultTypeDef = TypedDict(
+    "DescribeDomainControllersResultTypeDef",
+    {"DomainControllers": List["DomainControllerTypeDef"], "NextToken": str},
+    total=False,
+)
+
+DescribeEventTopicsResultTypeDef = TypedDict(
+    "DescribeEventTopicsResultTypeDef", {"EventTopics": List["EventTopicTypeDef"]}, total=False
+)
+
+DescribeLDAPSSettingsResultTypeDef = TypedDict(
+    "DescribeLDAPSSettingsResultTypeDef",
+    {"LDAPSSettingsInfo": List["LDAPSSettingInfoTypeDef"], "NextToken": str},
+    total=False,
+)
+
+DescribeSharedDirectoriesResultTypeDef = TypedDict(
+    "DescribeSharedDirectoriesResultTypeDef",
+    {"SharedDirectories": List["SharedDirectoryTypeDef"], "NextToken": str},
+    total=False,
+)
+
+DescribeSnapshotsResultTypeDef = TypedDict(
+    "DescribeSnapshotsResultTypeDef",
+    {"Snapshots": List["SnapshotTypeDef"], "NextToken": str},
+    total=False,
+)
+
 DescribeTrustsResultTypeDef = TypedDict(
-    "DescribeTrustsResultTypeDef", {"Trusts": List[TrustTypeDef], "NextToken": str}, total=False
+    "DescribeTrustsResultTypeDef", {"Trusts": List["TrustTypeDef"], "NextToken": str}, total=False
 )
 
 DirectoryConnectSettingsTypeDef = TypedDict(
@@ -427,133 +518,42 @@ DirectoryVpcSettingsTypeDef = TypedDict(
     "DirectoryVpcSettingsTypeDef", {"VpcId": str, "SubnetIds": List[str]}
 )
 
-DirectoryLimitsTypeDef = TypedDict(
-    "DirectoryLimitsTypeDef",
-    {
-        "CloudOnlyDirectoriesLimit": int,
-        "CloudOnlyDirectoriesCurrentCount": int,
-        "CloudOnlyDirectoriesLimitReached": bool,
-        "CloudOnlyMicrosoftADLimit": int,
-        "CloudOnlyMicrosoftADCurrentCount": int,
-        "CloudOnlyMicrosoftADLimitReached": bool,
-        "ConnectedDirectoriesLimit": int,
-        "ConnectedDirectoriesCurrentCount": int,
-        "ConnectedDirectoriesLimitReached": bool,
-    },
-    total=False,
-)
-
 GetDirectoryLimitsResultTypeDef = TypedDict(
-    "GetDirectoryLimitsResultTypeDef", {"DirectoryLimits": DirectoryLimitsTypeDef}, total=False
-)
-
-SnapshotLimitsTypeDef = TypedDict(
-    "SnapshotLimitsTypeDef",
-    {
-        "ManualSnapshotsLimit": int,
-        "ManualSnapshotsCurrentCount": int,
-        "ManualSnapshotsLimitReached": bool,
-    },
-    total=False,
+    "GetDirectoryLimitsResultTypeDef", {"DirectoryLimits": "DirectoryLimitsTypeDef"}, total=False
 )
 
 GetSnapshotLimitsResultTypeDef = TypedDict(
-    "GetSnapshotLimitsResultTypeDef", {"SnapshotLimits": SnapshotLimitsTypeDef}, total=False
+    "GetSnapshotLimitsResultTypeDef", {"SnapshotLimits": "SnapshotLimitsTypeDef"}, total=False
 )
 
 IpRouteTypeDef = TypedDict("IpRouteTypeDef", {"CidrIp": str, "Description": str}, total=False)
 
-CertificateInfoTypeDef = TypedDict(
-    "CertificateInfoTypeDef",
-    {
-        "CertificateId": str,
-        "CommonName": str,
-        "State": Literal[
-            "Registering",
-            "Registered",
-            "RegisterFailed",
-            "Deregistering",
-            "Deregistered",
-            "DeregisterFailed",
-        ],
-        "ExpiryDateTime": datetime,
-    },
-    total=False,
-)
-
 ListCertificatesResultTypeDef = TypedDict(
     "ListCertificatesResultTypeDef",
-    {"NextToken": str, "CertificatesInfo": List[CertificateInfoTypeDef]},
-    total=False,
-)
-
-IpRouteInfoTypeDef = TypedDict(
-    "IpRouteInfoTypeDef",
-    {
-        "DirectoryId": str,
-        "CidrIp": str,
-        "IpRouteStatusMsg": Literal[
-            "Adding", "Added", "Removing", "Removed", "AddFailed", "RemoveFailed"
-        ],
-        "AddedDateTime": datetime,
-        "IpRouteStatusReason": str,
-        "Description": str,
-    },
+    {"NextToken": str, "CertificatesInfo": List["CertificateInfoTypeDef"]},
     total=False,
 )
 
 ListIpRoutesResultTypeDef = TypedDict(
     "ListIpRoutesResultTypeDef",
-    {"IpRoutesInfo": List[IpRouteInfoTypeDef], "NextToken": str},
-    total=False,
-)
-
-LogSubscriptionTypeDef = TypedDict(
-    "LogSubscriptionTypeDef",
-    {"DirectoryId": str, "LogGroupName": str, "SubscriptionCreatedDateTime": datetime},
+    {"IpRoutesInfo": List["IpRouteInfoTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListLogSubscriptionsResultTypeDef = TypedDict(
     "ListLogSubscriptionsResultTypeDef",
-    {"LogSubscriptions": List[LogSubscriptionTypeDef], "NextToken": str},
-    total=False,
-)
-
-SchemaExtensionInfoTypeDef = TypedDict(
-    "SchemaExtensionInfoTypeDef",
-    {
-        "DirectoryId": str,
-        "SchemaExtensionId": str,
-        "Description": str,
-        "SchemaExtensionStatus": Literal[
-            "Initializing",
-            "CreatingSnapshot",
-            "UpdatingSchema",
-            "Replicating",
-            "CancelInProgress",
-            "RollbackInProgress",
-            "Cancelled",
-            "Failed",
-            "Completed",
-        ],
-        "SchemaExtensionStatusReason": str,
-        "StartDateTime": datetime,
-        "EndDateTime": datetime,
-    },
+    {"LogSubscriptions": List["LogSubscriptionTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListSchemaExtensionsResultTypeDef = TypedDict(
     "ListSchemaExtensionsResultTypeDef",
-    {"SchemaExtensionsInfo": List[SchemaExtensionInfoTypeDef], "NextToken": str},
+    {"SchemaExtensionsInfo": List["SchemaExtensionInfoTypeDef"], "NextToken": str},
     total=False,
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
-
 ListTagsForResourceResultTypeDef = TypedDict(
-    "ListTagsForResourceResultTypeDef", {"Tags": List[TagTypeDef], "NextToken": str}, total=False
+    "ListTagsForResourceResultTypeDef", {"Tags": List["TagTypeDef"], "NextToken": str}, total=False
 )
 
 PaginatorConfigTypeDef = TypedDict(
